@@ -74,7 +74,7 @@ class LiteNetServer:
                     if client != addr:
                         if self.clients[client]["alive"]:
                             self.clients.get(client)["connection"].send(
-                                msg.encode(self.encoding) + b" " * (self.header - len(msg.encode(self.encoding)))
+                                str(len(msg.encode(self.encoding))).encode(self.encoding) + b" " * (self.header - len(msg.encode(self.encoding)))
                             )
 
                             self.clients.get(client)["connection"].send(
